@@ -12,7 +12,7 @@
     """
     '分词' 函数的返回列表版本.
     """
-    返回 jieba.lcut(*参数, **关键词参数)
+    返回 列表型(分词(*参数, **关键词参数))
 
 套路 分词_搜索引擎(语句, HMM=真):
     """
@@ -24,7 +24,7 @@
     """
     '分词_搜索引擎' 函数的返回列表版本.
     """
-    返回 jieba.lcut_for_search(*参数, **关键词参数)
+    返回 列表型(分词_搜索引擎(*参数, **关键词参数))
 
 套路 添加词语(词语, 词频=空, 词性=空):
     """
